@@ -25,17 +25,17 @@
  ***************************************************************************/
 
 // KDE includes
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kstdaction.h>
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kaction.h>
-#include <kshortcut.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaction.h>
+#include <tdeshortcut.h>
 #include <kdebug.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kiconloader.h>
-#include <kactionclasses.h>
+#include <tdeactionclasses.h>
 
 // application specific includes
 #include "smb4ksharesiconview_part.h"
@@ -47,8 +47,8 @@
 #include "../core/smb4ksettings.h"
 
 
-KInstance *Smb4KSharesIconViewPartFactory::m_instance = 0L;
-KAboutData *Smb4KSharesIconViewPartFactory::m_about = 0L;
+TDEInstance *Smb4KSharesIconViewPartFactory::m_instance = 0L;
+TDEAboutData *Smb4KSharesIconViewPartFactory::m_about = 0L;
 
 
 Smb4KSharesIconViewPart::Smb4KSharesIconViewPart( TQWidget *parentWidget, const char *widgetName,
@@ -105,24 +105,24 @@ Smb4KSharesIconViewPart::~Smb4KSharesIconViewPart()
 void Smb4KSharesIconViewPart::setupActions()
 {
   // Create the actions:
-  KAction *unmount =   new KAction( i18n( "&Unmount" ), "hdd_unmount", KShortcut( CTRL+Key_U ),
+  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
                                     this, TQT_SLOT( slotUnmountShare() ),
                                     actionCollection(), "unmount_action" );
 #ifdef __linux__
-  KAction *force =     new KAction( i18n( "&Force Unmounting" ), "hdd_unmount", KShortcut( CTRL+Key_F ),
+  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk", TDEShortcut( CTRL+Key_F ),
                                     this, TQT_SLOT( slotForceUnmountShare() ),
                                     actionCollection(), "force_unmount_action" );
 #endif
-  KAction *all =       new KAction( i18n( "U&nmount All" ), "gear", KShortcut( CTRL+Key_N ),
+  TDEAction *all =       new TDEAction( i18n( "U&nmount All" ), "gear", TDEShortcut( CTRL+Key_N ),
                                     this, TQT_SLOT( slotUnmountAllShares() ),
                                     actionCollection(), "unmount_all_action" );
-  KAction *sync =      new KAction( i18n( "S&ynchronize" ), "bottom", KShortcut( CTRL+Key_Y ),
+  TDEAction *sync =      new TDEAction( i18n( "S&ynchronize" ), "go-bottom", TDEShortcut( CTRL+Key_Y ),
                                     this, TQT_SLOT( slotSynchronize() ),
                                     actionCollection(), "synchronize_action" );
-  KAction *konsole =   new KAction( i18n( "Open with Konso&le" ), "terminal", KShortcut( CTRL+Key_L ),
+  TDEAction *konsole =   new TDEAction( i18n( "Open with Konso&le" ), "terminal", TDEShortcut( CTRL+Key_L ),
                                     this, TQT_SLOT( slotKonsole() ),
                                     actionCollection(), "konsole_action" );
-  KAction *konq =      new KAction( i18n( "Open with &Konqueror" ), "kfm_home", KShortcut( CTRL+Key_K ),
+  TDEAction *konq =      new TDEAction( i18n( "Open with &Konqueror" ), "kfm_home", TDEShortcut( CTRL+Key_K ),
                                     this, TQT_SLOT( slotFilemanager() ),
                                     actionCollection(), "filemanager_action" );
 
@@ -137,8 +137,8 @@ void Smb4KSharesIconViewPart::setupActions()
   konq->setEnabled( false );
 
   // Insert the actions into the menu:
-  m_menu = new KActionMenu( this, "SharesIconViewMenu" );
-  m_menu->popupMenu()->insertTitle( SmallIcon( "hdd_mount" ), i18n( "Shares" ), 0 );
+  m_menu = new TDEActionMenu( this, "SharesIconViewMenu" );
+  m_menu->popupMenu()->insertTitle( SmallIcon( "drive-harddisk-mounted" ), i18n( "Shares" ), 0 );
   m_menu->insert( unmount, -1 );
 #ifdef __linux__
   m_menu->insert( force, -1 );
@@ -193,7 +193,7 @@ void Smb4KSharesIconViewPart::customEvent( TQCustomEvent *e )
     }
     case EVENT_SET_FOCUS:
     {
-      KIconView *view = static_cast<KIconView *>( m_widget );
+      TDEIconView *view = static_cast<TDEIconView *>( m_widget );
 
       if ( view->count() != 0 )
       {
@@ -224,12 +224,12 @@ void Smb4KSharesIconViewPart::slotContextMenuRequested( TQIconViewItem *item, co
 {
   if ( item )
   {
-    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "hdd_mount" ),
+    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "drive-harddisk-mounted" ),
                                       static_cast<Smb4KSharesIconViewItem *>( item )->shareObject()->name() );
   }
   else
   {
-    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "hdd_mount" ), i18n( "Shares" ) );
+    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "drive-harddisk-mounted" ), i18n( "Shares" ) );
   }
 
   m_menu->popupMenu()->exec( pos, 0 );
@@ -238,7 +238,7 @@ void Smb4KSharesIconViewPart::slotContextMenuRequested( TQIconViewItem *item, co
 
 void Smb4KSharesIconViewPart::slotSelectionChanged( TQIconViewItem *item )
 {
-  // NOTE: Here we only enable or disable the KActions. All other things
+  // NOTE: Here we only enable or disable the TDEActions. All other things
   // are done in the Smb4KSharesIconView class.
 
   // This slot is used to enable or disable the actions when the user
@@ -277,7 +277,7 @@ void Smb4KSharesIconViewPart::slotSelectionChanged( TQIconViewItem *item )
 
 void Smb4KSharesIconViewPart::slotMouseButtonPressed( TQIconViewItem *item )
 {
-  // NOTE: Here we only enable or disable the KActions. All other things
+  // NOTE: Here we only enable or disable the TDEActions. All other things
   // are done in the Smb4KSharesIconView class.
 
   // Here we do all the stuff that cannot be done in
@@ -542,14 +542,14 @@ TQObject *parent, const char *name, const char *, const TQStringList & )
 }
 
 
-KInstance *Smb4KSharesIconViewPartFactory::instance()
+TDEInstance *Smb4KSharesIconViewPartFactory::instance()
 {
   if( !m_instance )
   {
-    m_about = new KAboutData( "smb4ksharesiconviewpart", I18N_NOOP( "Smb4KSharesIconViewPart" ), "1.0" );
+    m_about = new TDEAboutData( "smb4ksharesiconviewpart", I18N_NOOP( "Smb4KSharesIconViewPart" ), "1.0" );
     m_about->addAuthor("Alexander Reinholdt", 0, "dustpuppy@users.berlios.de");
-    m_about->setLicense( KAboutData::License_GPL );
-    m_instance = new KInstance( m_about );
+    m_about->setLicense( TDEAboutData::License_GPL );
+    m_instance = new TDEInstance( m_about );
   }
 
   return m_instance;
@@ -564,7 +564,7 @@ extern "C"
 {
   void *init_libsmb4ksharesiconview()
   {
-    KGlobal::locale()->insertCatalogue( "smb4k" );
+    TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KSharesIconViewPartFactory;
   }
 }
